# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class PrinterStateEnum(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    OPERATIONAL = "Operational"
    PAUSED = "Paused"
    CANCELLING = "Cancelling"
    PRINTING = "Printing"
    PAUSING = "Pausing"
    SDREADY = "sdReady"
    ERROR = "Error"
    READYPRINTER_READY = "ReadyPrinter Ready"
    CLOSEDORERROR = "closedOrError"
    OFFLINE = "Offline"
    OPENING_SERIAL_CONNECTION = "Opening serial connection"
    CONNECTION = "Connection"
    RESUMING = "Resuming"
    FINISHING = "Finishing"
    PRINTERSTATECHANGED = "PrinterStateChanged"
    CONNECTED = "Connected"
    DISCONNECTED = "Disconnected"
    PRINTERRESET = "PrinterReset"
    FIRMWAREDATA = "FirmwareData"

    allowable_values = [OPERATIONAL, PAUSED, CANCELLING, PRINTING, PAUSING, SDREADY, ERROR, READYPRINTER_READY, CLOSEDORERROR, OFFLINE, OPENING_SERIAL_CONNECTION, CONNECTION, RESUMING, FINISHING, PRINTERSTATECHANGED, CONNECTED, DISCONNECTED, PRINTERRESET, FIRMWAREDATA]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """PrinterStateEnum - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrinterStateEnum):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrinterStateEnum):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class DeviceState(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'deleted': 'datetime',
        'status': 'StatusEnum',
        'command': 'DeviceStateCommandEnum',
        'ansible_facts': 'dict(str, object)',
        'ansible_extra_vars': 'dict(str, object)',
        'created_dt': 'datetime',
        'device': 'int'
    }

    attribute_map = {
        'id': 'id',
        'deleted': 'deleted',
        'status': 'status',
        'command': 'command',
        'ansible_facts': 'ansible_facts',
        'ansible_extra_vars': 'ansible_extra_vars',
        'created_dt': 'created_dt',
        'device': 'device'
    }

    def __init__(self, id=None, deleted=None, status=None, command=None, ansible_facts=None, ansible_extra_vars=None, created_dt=None, device=None, local_vars_configuration=None):  # noqa: E501
        """DeviceState - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._deleted = None
        self._status = None
        self._command = None
        self._ansible_facts = None
        self._ansible_extra_vars = None
        self._created_dt = None
        self._device = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if deleted is not None:
            self.deleted = deleted
        if status is not None:
            self.status = status
        if command is not None:
            self.command = command
        if ansible_facts is not None:
            self.ansible_facts = ansible_facts
        if ansible_extra_vars is not None:
            self.ansible_extra_vars = ansible_extra_vars
        if created_dt is not None:
            self.created_dt = created_dt
        self.device = device

    @property
    def id(self):
        """Gets the id of this DeviceState.  # noqa: E501


        :return: The id of this DeviceState.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeviceState.


        :param id: The id of this DeviceState.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def deleted(self):
        """Gets the deleted of this DeviceState.  # noqa: E501


        :return: The deleted of this DeviceState.  # noqa: E501
        :rtype: datetime
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this DeviceState.


        :param deleted: The deleted of this DeviceState.  # noqa: E501
        :type deleted: datetime
        """

        self._deleted = deleted

    @property
    def status(self):
        """Gets the status of this DeviceState.  # noqa: E501


        :return: The status of this DeviceState.  # noqa: E501
        :rtype: StatusEnum
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DeviceState.


        :param status: The status of this DeviceState.  # noqa: E501
        :type status: StatusEnum
        """

        self._status = status

    @property
    def command(self):
        """Gets the command of this DeviceState.  # noqa: E501


        :return: The command of this DeviceState.  # noqa: E501
        :rtype: DeviceStateCommandEnum
        """
        return self._command

    @command.setter
    def command(self, command):
        """Sets the command of this DeviceState.


        :param command: The command of this DeviceState.  # noqa: E501
        :type command: DeviceStateCommandEnum
        """

        self._command = command

    @property
    def ansible_facts(self):
        """Gets the ansible_facts of this DeviceState.  # noqa: E501


        :return: The ansible_facts of this DeviceState.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._ansible_facts

    @ansible_facts.setter
    def ansible_facts(self, ansible_facts):
        """Sets the ansible_facts of this DeviceState.


        :param ansible_facts: The ansible_facts of this DeviceState.  # noqa: E501
        :type ansible_facts: dict(str, object)
        """

        self._ansible_facts = ansible_facts

    @property
    def ansible_extra_vars(self):
        """Gets the ansible_extra_vars of this DeviceState.  # noqa: E501


        :return: The ansible_extra_vars of this DeviceState.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._ansible_extra_vars

    @ansible_extra_vars.setter
    def ansible_extra_vars(self, ansible_extra_vars):
        """Sets the ansible_extra_vars of this DeviceState.


        :param ansible_extra_vars: The ansible_extra_vars of this DeviceState.  # noqa: E501
        :type ansible_extra_vars: dict(str, object)
        """

        self._ansible_extra_vars = ansible_extra_vars

    @property
    def created_dt(self):
        """Gets the created_dt of this DeviceState.  # noqa: E501


        :return: The created_dt of this DeviceState.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this DeviceState.


        :param created_dt: The created_dt of this DeviceState.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def device(self):
        """Gets the device of this DeviceState.  # noqa: E501


        :return: The device of this DeviceState.  # noqa: E501
        :rtype: int
        """
        return self._device

    @device.setter
    def device(self, device):
        """Sets the device of this DeviceState.


        :param device: The device of this DeviceState.  # noqa: E501
        :type device: int
        """
        if self.local_vars_configuration.client_side_validation and device is None:  # noqa: E501
            raise ValueError("Invalid value for `device`, must not be `None`")  # noqa: E501

        self._device = device

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceState):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeviceState):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import printnanny_api_client
from printnanny_api_client.models.octo_print_device_key import OctoPrintDeviceKey  # noqa: E501
from printnanny_api_client.rest import ApiException

class TestOctoPrintDeviceKey(unittest.TestCase):
    """OctoPrintDeviceKey unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OctoPrintDeviceKey
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = printnanny_api_client.models.octo_print_device_key.OctoPrintDeviceKey()  # noqa: E501
        if include_optional :
            return OctoPrintDeviceKey(
                active_session = printnanny_api_client.models.print_session.PrintSession(
                    id = 56, 
                    created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    octoprint_device = 56, 
                    active = True, 
                    session = '', 
                    filepos = -2147483648, 
                    print_progress = -2147483648, 
                    time_elapsed = -2147483648, 
                    time_remaining = -2147483648, 
                    user = 56, 
                    printer_profile = 56, 
                    gcode_file = 56, 
                    gcode_filename = '', 
                    octoprint_job = {
                        'key' : null
                        }, 
                    print_job_status = null, 
                    url = '', 
                    datesegment = '', ), 
                ca_certs = {
                    'key' : ''
                    }, 
                cloudiot_device_configs = '', 
                cloudiot_device_name = '', 
                cloudiot_device_num_id = 56, 
                cloudiot_device_path = '', 
                cloudiot_device = {
                    'key' : null
                    }, 
                cores = -2147483648, 
                cpu_flags = [
                    ''
                    ], 
                created_dt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                fingerprint = '', 
                hardware = '', 
                id = 56, 
                manage_url = '', 
                model = '', 
                monitoring_active = True, 
                name = '', 
                octoprint_version = '', 
                pip_version = '', 
                platform = '', 
                plugin_version = '', 
                print_nanny_client_version = '', 
                private_key_checksum = '', 
                private_key = '', 
                public_key_checksum = '', 
                public_key = '', 
                python_version = '', 
                ram = -2147483648, 
                revision = '', 
                serial = '', 
                user = 56, 
                url = ''
            )
        else :
            return OctoPrintDeviceKey(
                ca_certs = {
                    'key' : ''
                    },
                cores = -2147483648,
                model = '',
                name = '',
                octoprint_version = '',
                pip_version = '',
                platform = '',
                plugin_version = '',
                print_nanny_client_version = '',
                public_key_checksum = '',
                python_version = '',
                ram = -2147483648,
                serial = '',
        )

    def testOctoPrintDeviceKey(self):
        """Test OctoPrintDeviceKey"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class AnsibleExtraVars(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'janus_version': 'str',
        'janus_libwebsockets_version': 'str',
        'janus_libnice_version': 'str',
        'janus_usrsctp_version': 'str',
        'janus_libsrtp_version': 'str',
        'tflite_version': 'str',
        'printnanny_cli_version': 'str',
        'libcamera_version': 'str'
    }

    attribute_map = {
        'janus_version': 'janus_version',
        'janus_libwebsockets_version': 'janus_libwebsockets_version',
        'janus_libnice_version': 'janus_libnice_version',
        'janus_usrsctp_version': 'janus_usrsctp_version',
        'janus_libsrtp_version': 'janus_libsrtp_version',
        'tflite_version': 'tflite_version',
        'printnanny_cli_version': 'printnanny_cli_version',
        'libcamera_version': 'libcamera_version'
    }

    def __init__(self, janus_version=None, janus_libwebsockets_version=None, janus_libnice_version=None, janus_usrsctp_version=None, janus_libsrtp_version=None, tflite_version=None, printnanny_cli_version=None, libcamera_version=None, local_vars_configuration=None):  # noqa: E501
        """AnsibleExtraVars - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._janus_version = None
        self._janus_libwebsockets_version = None
        self._janus_libnice_version = None
        self._janus_usrsctp_version = None
        self._janus_libsrtp_version = None
        self._tflite_version = None
        self._printnanny_cli_version = None
        self._libcamera_version = None
        self.discriminator = None

        self.janus_version = janus_version
        self.janus_libwebsockets_version = janus_libwebsockets_version
        self.janus_libnice_version = janus_libnice_version
        self.janus_usrsctp_version = janus_usrsctp_version
        self.janus_libsrtp_version = janus_libsrtp_version
        self.tflite_version = tflite_version
        self.printnanny_cli_version = printnanny_cli_version
        self.libcamera_version = libcamera_version

    @property
    def janus_version(self):
        """Gets the janus_version of this AnsibleExtraVars.  # noqa: E501


        :return: The janus_version of this AnsibleExtraVars.  # noqa: E501
        :rtype: str
        """
        return self._janus_version

    @janus_version.setter
    def janus_version(self, janus_version):
        """Sets the janus_version of this AnsibleExtraVars.


        :param janus_version: The janus_version of this AnsibleExtraVars.  # noqa: E501
        :type janus_version: str
        """
        if self.local_vars_configuration.client_side_validation and janus_version is None:  # noqa: E501
            raise ValueError("Invalid value for `janus_version`, must not be `None`")  # noqa: E501

        self._janus_version = janus_version

    @property
    def janus_libwebsockets_version(self):
        """Gets the janus_libwebsockets_version of this AnsibleExtraVars.  # noqa: E501


        :return: The janus_libwebsockets_version of this AnsibleExtraVars.  # noqa: E501
        :rtype: str
        """
        return self._janus_libwebsockets_version

    @janus_libwebsockets_version.setter
    def janus_libwebsockets_version(self, janus_libwebsockets_version):
        """Sets the janus_libwebsockets_version of this AnsibleExtraVars.


        :param janus_libwebsockets_version: The janus_libwebsockets_version of this AnsibleExtraVars.  # noqa: E501
        :type janus_libwebsockets_version: str
        """
        if self.local_vars_configuration.client_side_validation and janus_libwebsockets_version is None:  # noqa: E501
            raise ValueError("Invalid value for `janus_libwebsockets_version`, must not be `None`")  # noqa: E501

        self._janus_libwebsockets_version = janus_libwebsockets_version

    @property
    def janus_libnice_version(self):
        """Gets the janus_libnice_version of this AnsibleExtraVars.  # noqa: E501


        :return: The janus_libnice_version of this AnsibleExtraVars.  # noqa: E501
        :rtype: str
        """
        return self._janus_libnice_version

    @janus_libnice_version.setter
    def janus_libnice_version(self, janus_libnice_version):
        """Sets the janus_libnice_version of this AnsibleExtraVars.


        :param janus_libnice_version: The janus_libnice_version of this AnsibleExtraVars.  # noqa: E501
        :type janus_libnice_version: str
        """
        if self.local_vars_configuration.client_side_validation and janus_libnice_version is None:  # noqa: E501
            raise ValueError("Invalid value for `janus_libnice_version`, must not be `None`")  # noqa: E501

        self._janus_libnice_version = janus_libnice_version

    @property
    def janus_usrsctp_version(self):
        """Gets the janus_usrsctp_version of this AnsibleExtraVars.  # noqa: E501


        :return: The janus_usrsctp_version of this AnsibleExtraVars.  # noqa: E501
        :rtype: str
        """
        return self._janus_usrsctp_version

    @janus_usrsctp_version.setter
    def janus_usrsctp_version(self, janus_usrsctp_version):
        """Sets the janus_usrsctp_version of this AnsibleExtraVars.


        :param janus_usrsctp_version: The janus_usrsctp_version of this AnsibleExtraVars.  # noqa: E501
        :type janus_usrsctp_version: str
        """
        if self.local_vars_configuration.client_side_validation and janus_usrsctp_version is None:  # noqa: E501
            raise ValueError("Invalid value for `janus_usrsctp_version`, must not be `None`")  # noqa: E501

        self._janus_usrsctp_version = janus_usrsctp_version

    @property
    def janus_libsrtp_version(self):
        """Gets the janus_libsrtp_version of this AnsibleExtraVars.  # noqa: E501


        :return: The janus_libsrtp_version of this AnsibleExtraVars.  # noqa: E501
        :rtype: str
        """
        return self._janus_libsrtp_version

    @janus_libsrtp_version.setter
    def janus_libsrtp_version(self, janus_libsrtp_version):
        """Sets the janus_libsrtp_version of this AnsibleExtraVars.


        :param janus_libsrtp_version: The janus_libsrtp_version of this AnsibleExtraVars.  # noqa: E501
        :type janus_libsrtp_version: str
        """
        if self.local_vars_configuration.client_side_validation and janus_libsrtp_version is None:  # noqa: E501
            raise ValueError("Invalid value for `janus_libsrtp_version`, must not be `None`")  # noqa: E501

        self._janus_libsrtp_version = janus_libsrtp_version

    @property
    def tflite_version(self):
        """Gets the tflite_version of this AnsibleExtraVars.  # noqa: E501


        :return: The tflite_version of this AnsibleExtraVars.  # noqa: E501
        :rtype: str
        """
        return self._tflite_version

    @tflite_version.setter
    def tflite_version(self, tflite_version):
        """Sets the tflite_version of this AnsibleExtraVars.


        :param tflite_version: The tflite_version of this AnsibleExtraVars.  # noqa: E501
        :type tflite_version: str
        """
        if self.local_vars_configuration.client_side_validation and tflite_version is None:  # noqa: E501
            raise ValueError("Invalid value for `tflite_version`, must not be `None`")  # noqa: E501

        self._tflite_version = tflite_version

    @property
    def printnanny_cli_version(self):
        """Gets the printnanny_cli_version of this AnsibleExtraVars.  # noqa: E501


        :return: The printnanny_cli_version of this AnsibleExtraVars.  # noqa: E501
        :rtype: str
        """
        return self._printnanny_cli_version

    @printnanny_cli_version.setter
    def printnanny_cli_version(self, printnanny_cli_version):
        """Sets the printnanny_cli_version of this AnsibleExtraVars.


        :param printnanny_cli_version: The printnanny_cli_version of this AnsibleExtraVars.  # noqa: E501
        :type printnanny_cli_version: str
        """
        if self.local_vars_configuration.client_side_validation and printnanny_cli_version is None:  # noqa: E501
            raise ValueError("Invalid value for `printnanny_cli_version`, must not be `None`")  # noqa: E501

        self._printnanny_cli_version = printnanny_cli_version

    @property
    def libcamera_version(self):
        """Gets the libcamera_version of this AnsibleExtraVars.  # noqa: E501


        :return: The libcamera_version of this AnsibleExtraVars.  # noqa: E501
        :rtype: str
        """
        return self._libcamera_version

    @libcamera_version.setter
    def libcamera_version(self, libcamera_version):
        """Sets the libcamera_version of this AnsibleExtraVars.


        :param libcamera_version: The libcamera_version of this AnsibleExtraVars.  # noqa: E501
        :type libcamera_version: str
        """
        if self.local_vars_configuration.client_side_validation and libcamera_version is None:  # noqa: E501
            raise ValueError("Invalid value for `libcamera_version`, must not be `None`")  # noqa: E501

        self._libcamera_version = libcamera_version

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnsibleExtraVars):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AnsibleExtraVars):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    printnanny-api-client

    Official API client library for print-nanny.com  # noqa: E501

    The version of the OpenAPI document: 0.0.0
    Contact: leigh@print-nanny.com
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from printnanny_api_client.configuration import Configuration


class Release(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'ansible_extra_vars': 'AnsibleExtraVars',
        'created_dt': 'datetime',
        'release_channel': 'ReleaseChannelEnum'
    }

    attribute_map = {
        'id': 'id',
        'ansible_extra_vars': 'ansible_extra_vars',
        'created_dt': 'created_dt',
        'release_channel': 'release_channel'
    }

    def __init__(self, id=None, ansible_extra_vars=None, created_dt=None, release_channel=None, local_vars_configuration=None):  # noqa: E501
        """Release - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._ansible_extra_vars = None
        self._created_dt = None
        self._release_channel = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.ansible_extra_vars = ansible_extra_vars
        if created_dt is not None:
            self.created_dt = created_dt
        if release_channel is not None:
            self.release_channel = release_channel

    @property
    def id(self):
        """Gets the id of this Release.  # noqa: E501


        :return: The id of this Release.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Release.


        :param id: The id of this Release.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def ansible_extra_vars(self):
        """Gets the ansible_extra_vars of this Release.  # noqa: E501


        :return: The ansible_extra_vars of this Release.  # noqa: E501
        :rtype: AnsibleExtraVars
        """
        return self._ansible_extra_vars

    @ansible_extra_vars.setter
    def ansible_extra_vars(self, ansible_extra_vars):
        """Sets the ansible_extra_vars of this Release.


        :param ansible_extra_vars: The ansible_extra_vars of this Release.  # noqa: E501
        :type ansible_extra_vars: AnsibleExtraVars
        """
        if self.local_vars_configuration.client_side_validation and ansible_extra_vars is None:  # noqa: E501
            raise ValueError("Invalid value for `ansible_extra_vars`, must not be `None`")  # noqa: E501

        self._ansible_extra_vars = ansible_extra_vars

    @property
    def created_dt(self):
        """Gets the created_dt of this Release.  # noqa: E501


        :return: The created_dt of this Release.  # noqa: E501
        :rtype: datetime
        """
        return self._created_dt

    @created_dt.setter
    def created_dt(self, created_dt):
        """Sets the created_dt of this Release.


        :param created_dt: The created_dt of this Release.  # noqa: E501
        :type created_dt: datetime
        """

        self._created_dt = created_dt

    @property
    def release_channel(self):
        """Gets the release_channel of this Release.  # noqa: E501


        :return: The release_channel of this Release.  # noqa: E501
        :rtype: ReleaseChannelEnum
        """
        return self._release_channel

    @release_channel.setter
    def release_channel(self, release_channel):
        """Sets the release_channel of this Release.


        :param release_channel: The release_channel of this Release.  # noqa: E501
        :type release_channel: ReleaseChannelEnum
        """

        self._release_channel = release_channel

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Release):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Release):
            return True

        return self.to_dict() != other.to_dict()
